#include <XSUser/Python/PySpectrum.h>

#include <XSContainer.h>
#include <XSModel/Data/DataInputRecord.h>
#include <XSModel/DataFactory/DataFactory.h>
#include <XSModel/DataFactory/XspecRegistry.h>
#include <XSModel/GlobalContainer/DataContainer.h>
#include <XSUtil/Parse/XSparse.h>
#include <memory>

PyObject*
_pyXspec_readSpectrum(PyObject *self, PyObject *args)
{
   using namespace std;
   using namespace XSContainer;
   
   const char *dataFile=0, *bckFile=0, *rspFile=0, *arfFile=0;
   size_t rowNum=0;
   if (!PyArg_ParseTuple(args,"zzzzI", &dataFile, &bckFile,
                        &rspFile, &arfFile, &rowNum))
      return NULL;
   if (XSparse::isBlank(dataFile))
   {
      string msg("Error: Data file name is required.");
      PyErr_SetString(PyExc_Exception, msg.c_str());
      return NULL;
   }
   
   try
   {
      const int specNum = static_cast<int>(datasets->numberOfSpectra()) + 1;
      const size_t groupNum = 1;
      IntegerArray specNums(1, specNum);
      IntegerArray specRows(1, rowNum);
      const string fileName(dataFile);
      DataInputRecord record(fileName, specNums, groupNum, specRows);
      DataPrototype* prot = xsRegistry->returnPrototype(fileName);
      std::auto_ptr<DataSet> dataset(prot->MakeDataSet());
      dataset->initialize(prot, record);
      dataset->dataGroup(groupNum);
      dataset->setData(specNums[0], specRows[0]);
      datasets->addToList(dataset.release());
      datasets->showData(false);
      datasets->Notify();
   }
   catch (...)
   {
      string msg("Error occurred while loading new data set.");
      PyErr_SetString(PyExc_Exception, msg.c_str());
      return NULL;
   }
   
   return Py_BuildValue("i",0);
}

